@@ -4,7 +4,8 @@
 #'
 #'
 #' 	  Data format should be in 'long' format, where each PRO-CTCAE item is a
-#' 	  variable/column.
+#' 	  variable/column. AUC calculations will only include subjects with non-
+#' 	  missing baseline values (within each PRO-CTCAE item).
 #'
 #' @param dsn A data.frame object with PRO-CTCAE data
 #' @param id_var A character string. Name of ID variable differentiating each
@@ -152,12 +153,31 @@ toxAUC = function(dsn,
     # -- AUC at the group level (area under the mean AE grade curve)
     # ------------------------------------------------------------------------------
 
-    dsn_slice = dsn[,c(id_var, cycle_var, arm_var, ref)]
-
     # -- Group-level AE means data
-    group_auc = stats::aggregate(data = dsn_slice[,c(arm_var, cycle_var, ref)],
-                          stats::formula(paste0(". ~", arm_var,"+", cycle_var)),
-                          mean)
+    # -- Only subjects with existing baseline values are considered for AUC calculation.
+    for(ref_i in ref){
+      dsn_slice = dsn[,c(id_var, cycle_var, arm_var, ref_i)]
+      dsn_slice_no_NA = dsn_slice[dsn_slice[,cycle_var]==baseline_val & !is.na(dsn_slice[,ref_i]),]
+      dsn_slice_ids = unique(dsn_slice_no_NA[,id_var])
+
+      dsn_slice = dsn_slice[dsn_slice[,id_var] %in% dsn_slice_ids,]
+
+      if(which(ref == ref_i) == 1){
+        group_auc = stats::aggregate(data = dsn_slice[,c(arm_var, cycle_var, ref_i)],
+                                     stats::formula(paste0(". ~", arm_var,"+", cycle_var)),
+                                     mean)
+      }else if(which(ref == ref_i) > 1){
+        group_auc = merge(group_auc,
+                          stats::aggregate(data = dsn_slice[,c(arm_var, cycle_var, ref_i)],
+                                           stats::formula(paste0(". ~", arm_var,"+", cycle_var)),
+                                           mean),
+                          by = c(arm_var, cycle_var),
+                          all = TRUE)
+
+      }
+    }
+
+    group_auc = group_auc[with(group_auc, order(group_auc[,cycle_var], group_auc[,arm_var])), ]
 
     # -- Create data frame for AUC to be attached
     group_out1 = data.frame(arm = unique(group_auc[,arm_var]))
@@ -465,7 +485,7 @@ toxAUC = function(dsn,
 
         names(anno_tab) = c("",
                             "Worsening [solid area]",
-                            "Improvment [striped area]")
+                            "Improvement [striped area]")
 
         ribbon_dat = ribbon_plot[[i]]
 
@@ -573,7 +593,7 @@ toxAUC = function(dsn,
 
         names(anno_tab) = c("",
                             "Worsening [solid area]",
-                            "Improvment [striped area]")
+                            "Improvement [striped area]")
 
         auc_tab_out = as.data.frame(t(anno_tab)[2:3,], stringsAsFactors = FALSE)
         names(auc_tab_out) = t(anno_tab)[1,]
@@ -614,7 +634,7 @@ toxAUC = function(dsn,
           rownames(anno_tab) = NULL
           names(anno_tab) = c("",
                               "Worsening [solid area]",
-                              "Improvment [striped area]")
+                              "Improvement [striped area]")
         }
 
 
@@ -656,7 +676,7 @@ toxAUC = function(dsn,
           rownames(anno_tab_boot) = NULL
           names(anno_tab_boot) = c("",
                                    "Worsening [solid area]",
-                                   "Improvment [striped area]")
+                                   "Improvement [striped area]")
 
           if(permute_tests == TRUE){
             anno_tab = rbind(anno_tab, anno_tab_boot[3,])
@@ -802,7 +822,7 @@ toxAUC = function(dsn,
 
         names(anno_tab) = c("",
                             "Worsening [solid area]",
-                            "Improvment [striped area]")
+                            "Improvement [striped area]")
 
         ribbon_dat = ribbon_plot[[i]]
 
@@ -929,7 +949,7 @@ toxAUC = function(dsn,
 
         names(anno_tab) = c("",
                             "Worsening [solid area]",
-                            "Improvment [striped area]")
+                            "Improvement [striped area]")
 
         ribbon_dat = ribbon_plot[[i]]
 
